@@ -62,6 +62,7 @@ __all__ = (
     "SimulationSoftwareSuiteTypeDef",
     "SourceTypeDef",
     "TemplateSummaryTypeDef",
+    "ToolTypeDef",
     "UploadConfigurationTypeDef",
     "VPCConfigResponseTypeDef",
     "VPCConfigTypeDef",
@@ -190,7 +191,11 @@ DeploymentJobTypeDef = TypedDict(
             "PostLaunchFileFailure",
             "BadPermissionError",
             "DownloadConditionFailed",
+            "BadLambdaAssociated",
             "InternalServerError",
+            "RobotApplicationDoesNotExist",
+            "DeploymentFleetDoesNotExist",
+            "FleetDeploymentTimeout",
         ],
         "createdAt": datetime,
     },
@@ -222,6 +227,8 @@ FailedCreateSimulationJobRequestTypeDef = TypedDict(
             "InternalServiceError",
             "RobotApplicationCrash",
             "SimulationApplicationCrash",
+            "RobotApplicationHealthCheckFailure",
+            "SimulationApplicationHealthCheckFailure",
             "BadPermissionsRobotApplication",
             "BadPermissionsSimulationApplication",
             "BadPermissionsS3Object",
@@ -233,6 +240,7 @@ FailedCreateSimulationJobRequestTypeDef = TypedDict(
             "InvalidBundleRobotApplication",
             "InvalidBundleSimulationApplication",
             "InvalidS3Resource",
+            "ThrottlingError",
             "LimitExceeded",
             "MismatchedEtag",
             "RobotApplicationVersionMismatchedEtag",
@@ -370,6 +378,8 @@ _OptionalRobotApplicationConfigTypeDef = TypedDict(
         "applicationVersion": str,
         "uploadConfigurations": List["UploadConfigurationTypeDef"],
         "useDefaultUploadConfigurations": bool,
+        "tools": List["ToolTypeDef"],
+        "useDefaultTools": bool,
     },
     total=False,
 )
@@ -430,7 +440,11 @@ RobotDeploymentTypeDef = TypedDict(
             "PostLaunchFileFailure",
             "BadPermissionError",
             "DownloadConditionFailed",
+            "BadLambdaAssociated",
             "InternalServerError",
+            "RobotApplicationDoesNotExist",
+            "DeploymentFleetDoesNotExist",
+            "FleetDeploymentTimeout",
         ],
     },
     total=False,
@@ -491,6 +505,8 @@ _OptionalSimulationApplicationConfigTypeDef = TypedDict(
         "uploadConfigurations": List["UploadConfigurationTypeDef"],
         "worldConfigs": List["WorldConfigTypeDef"],
         "useDefaultUploadConfigurations": bool,
+        "tools": List["ToolTypeDef"],
+        "useDefaultTools": bool,
     },
     total=False,
 )
@@ -616,6 +632,8 @@ SimulationJobTypeDef = TypedDict(
             "InternalServiceError",
             "RobotApplicationCrash",
             "SimulationApplicationCrash",
+            "RobotApplicationHealthCheckFailure",
+            "SimulationApplicationHealthCheckFailure",
             "BadPermissionsRobotApplication",
             "BadPermissionsSimulationApplication",
             "BadPermissionsS3Object",
@@ -627,6 +645,7 @@ SimulationJobTypeDef = TypedDict(
             "InvalidBundleRobotApplication",
             "InvalidBundleSimulationApplication",
             "InvalidS3Resource",
+            "ThrottlingError",
             "LimitExceeded",
             "MismatchedEtag",
             "RobotApplicationVersionMismatchedEtag",
@@ -683,6 +702,22 @@ TemplateSummaryTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredToolTypeDef = TypedDict("_RequiredToolTypeDef", {"name": str, "command": str})
+_OptionalToolTypeDef = TypedDict(
+    "_OptionalToolTypeDef",
+    {
+        "streamUI": bool,
+        "streamOutputToCloudWatch": bool,
+        "exitBehavior": Literal["FAIL", "RESTART"],
+    },
+    total=False,
+)
+
+
+class ToolTypeDef(_RequiredToolTypeDef, _OptionalToolTypeDef):
+    pass
+
+
 UploadConfigurationTypeDef = TypedDict(
     "UploadConfigurationTypeDef",
     {
@@ -802,7 +837,11 @@ CreateDeploymentJobResponseTypeDef = TypedDict(
             "PostLaunchFileFailure",
             "BadPermissionError",
             "DownloadConditionFailed",
+            "BadLambdaAssociated",
             "InternalServerError",
+            "RobotApplicationDoesNotExist",
+            "DeploymentFleetDoesNotExist",
+            "FleetDeploymentTimeout",
         ],
         "createdAt": datetime,
         "deploymentConfig": "DeploymentConfigTypeDef",
@@ -915,6 +954,8 @@ CreateSimulationJobResponseTypeDef = TypedDict(
             "InternalServiceError",
             "RobotApplicationCrash",
             "SimulationApplicationCrash",
+            "RobotApplicationHealthCheckFailure",
+            "SimulationApplicationHealthCheckFailure",
             "BadPermissionsRobotApplication",
             "BadPermissionsSimulationApplication",
             "BadPermissionsS3Object",
@@ -926,6 +967,7 @@ CreateSimulationJobResponseTypeDef = TypedDict(
             "InvalidBundleRobotApplication",
             "InvalidBundleSimulationApplication",
             "InvalidS3Resource",
+            "ThrottlingError",
             "LimitExceeded",
             "MismatchedEtag",
             "RobotApplicationVersionMismatchedEtag",
@@ -1049,7 +1091,11 @@ DescribeDeploymentJobResponseTypeDef = TypedDict(
             "PostLaunchFileFailure",
             "BadPermissionError",
             "DownloadConditionFailed",
+            "BadLambdaAssociated",
             "InternalServerError",
+            "RobotApplicationDoesNotExist",
+            "DeploymentFleetDoesNotExist",
+            "FleetDeploymentTimeout",
         ],
         "createdAt": datetime,
         "robotDeploymentSummary": List["RobotDeploymentTypeDef"],
@@ -1185,6 +1231,8 @@ DescribeSimulationJobResponseTypeDef = TypedDict(
             "InternalServiceError",
             "RobotApplicationCrash",
             "SimulationApplicationCrash",
+            "RobotApplicationHealthCheckFailure",
+            "SimulationApplicationHealthCheckFailure",
             "BadPermissionsRobotApplication",
             "BadPermissionsSimulationApplication",
             "BadPermissionsS3Object",
@@ -1196,6 +1244,7 @@ DescribeSimulationJobResponseTypeDef = TypedDict(
             "InvalidBundleRobotApplication",
             "InvalidBundleSimulationApplication",
             "InvalidS3Resource",
+            "ThrottlingError",
             "LimitExceeded",
             "MismatchedEtag",
             "RobotApplicationVersionMismatchedEtag",
@@ -1480,7 +1529,11 @@ SyncDeploymentJobResponseTypeDef = TypedDict(
             "PostLaunchFileFailure",
             "BadPermissionError",
             "DownloadConditionFailed",
+            "BadLambdaAssociated",
             "InternalServerError",
+            "RobotApplicationDoesNotExist",
+            "DeploymentFleetDoesNotExist",
+            "FleetDeploymentTimeout",
         ],
         "createdAt": datetime,
     },
